@@ -37,8 +37,6 @@ pub fn assert_data_valid(
     update_authority_is_signer: bool,
     is_updating: bool,
 ) -> ProgramResult {
-    let primary_sale_happened = existing_metadata.primary_sale_happened;
-
     if data.name.len() > MAX_NAME_LENGTH {
         return Err(MetadataError::NameTooLong.into());
     }
@@ -54,11 +52,6 @@ pub fn assert_data_valid(
     if data.seller_fee_basis_points > 10000 {
         return Err(MetadataError::InvalidBasisPoints.into());
     }
-
-    if data.seller_fee_basis_points != existing_metadata.data.seller_fee_basis_points && primary_sale_happened {
-      return Err(MetadataError::NotAllowedToChangeSellerFeeBasisPoints.into());
-    }
-
     if data.creators.is_some() {
         if let Some(creators) = &data.creators {
             if creators.len() > MAX_CREATOR_LIMIT {
@@ -70,8 +63,6 @@ pub fn assert_data_valid(
             } else {
                 let mut found = false;
                 let mut total: u8 = 0;
-
-
                 for i in 0..creators.len() {
                     let creator = &creators[i];
                     for j in (i + 1)..creators.len() {
@@ -127,27 +118,6 @@ pub fn assert_data_valid(
                     }
                 }
 
-                if let Some(existing_creators) = &existing_metadata.data.creators {
-                  for existing_creator in existing_creators {
-                    match creators
-                      .iter()
-                      .find(|c| c.address == existing_creator.address) {
-                      Some(creator) => {
-                        let fewer_shares = existing_creator.share > creator.share;
- 
-                        if existing_creator.verified && fewer_shares && primary_sale_happened {
-                          return Err(MetadataError::CannotAdjustVerifiedCreator.into())
-                        }
-                      }
-                      None => {
-                        if existing_creator.verified && primary_sale_happened {
-                          return Err(MetadataError::CannotRemoveVerifiedCreator.into())
-                        }
-                      }
-                    }
-                  }
-                }
-
                 if !found && !allow_direct_creator_writes && !is_updating {
                     return Err(MetadataError::MustBeOneOfCreators.into());
                 }
@@ -156,16 +126,7 @@ pub fn assert_data_valid(
                 }
             }
         }
-    } else {
-      if let Some(existing_creators) = &existing_metadata.data.creators {
-        let first_verified_creator = existing_creators.into_iter().find(|creator| creator.verified);
-
-        if first_verified_creator.is_some() && primary_sale_happened {
-          return Err(MetadataError::CannotWipeVerifiedCreators.into());
-        }
-      }
     }
-
     Ok(())
 }
 
@@ -951,7 +912,7 @@ pub fn process_create_metadata_accounts_logic(
     metadata.update_authority = update_authority_key;
     assert_valid_use(&data.uses, &None)?;
     metadata.uses = data.uses;
-    assert_collection_update_is_valid(&None, &data.collection)?;
+    assert_collection_update_is_valid(is_edition, &None, &data.collection)?;
     metadata.collection = data.collection;
     if add_token_standard {
         let token_standard = if is_edition {
@@ -965,7 +926,6 @@ pub fn process_create_metadata_accounts_logic(
     } else {
         metadata.token_standard = None;
     }
-
     puff_out_data_fields(&mut metadata);
 
     let edition_seeds = &[
